﻿using UnityEngine;
using UnityStandardAssets.ImageEffects;
using UnityStandardAssets.Characters.FirstPerson;
using System.Collections;

public class InspectionSystem : MonoBehaviour {

	private BlurOptimized blur;
	private FirstPersonController fpc;
	private Vector3 itemOrPos;
	private Quaternion itemOrRot;
	private Transform item;

	[HideInInspector]
	public bool inspecting = false;
	public Transform inspectionCamera;

	public static InspectionSystem instance;

	void Awake() {
		instance = this;
		blur = Camera.main.GetComponent<BlurOptimized>();
		fpc = GetComponent<FirstPersonController>();
	}

	public void InspectItem(Transform item) {
		Vector3 inspPos = inspectionCamera.position;
		Vector3 goalPos = new Vector3(inspPos.x, inspPos.y, inspPos.z + 1);
		Vector3 orPos = new Vector3(inspPos.x, inspPos.y, inspPos.z + 1.5f);
		this.item = item;
		itemOrPos = item.position;
		itemOrRot = item.rotation;
		inspecting = true;
		fpc.enabled = false;
		blur.enabled = true;
		StartCoroutine(LerpItemPos(orPos, goalPos));
		StartCoroutine(HandleItem());
	}

	public void StopInspecting() {
		inspecting = false;
		fpc.enabled = true;
		blur.enabled = false;
		item.position = itemOrPos;
		item.rotation = itemOrRot;
	}

	IEnumerator LerpItemPos(Vector3 orPos, Vector3 goalPos) {
		float tParam = 0;
		while (tParam < 1) {
			tParam += Time.deltaTime * 3;
			item.position = Vector3.Lerp(orPos, goalPos, tParam);
			yield return null;
		}
	}

	IEnumerator HandleItem() {
		float xDeg = item.eulerAngles.x;
		float yDeg = item.eulerAngles.y;
		float speed = 1;
		float friction = 1;
		Quaternion fromRotation;
		Quaternion toRotation;
		float lerpSpeed = 3;

		while (inspecting) {
			xDeg -= Input.GetAxis("Mouse X") * speed * friction;
			yDeg += Input.GetAxis("Mouse Y") * speed * friction;
			fromRotation = item.rotation;
			toRotation = Quaternion.Euler(yDeg, xDeg, 0);
			item.rotation = Quaternion.Lerp(fromRotation, toRotation, Time.deltaTime * lerpSpeed);
			if (Input.GetKeyDown(KeyCode.Escape)) StopInspecting();
			yield return null;
		}
	}

}
